## This file generated by InlineX::C2XS (version 0.27) using Inline::C (version 0.82)
package Math::GMPq::Random;
use strict;
use warnings;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

our $VERSION = '0.61';
$VERSION = eval $VERSION;
DynaLoader::bootstrap Math::GMPq::Random $VERSION;

@Math::GMPq::Random::EXPORT = ();
@Math::GMPq::Random::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking

1;
